Learn R Programming

MALDIcellassay (version 0.4.47)

calculateCurveFit: Calculate the fit for a dose-response curve

Description

Calculate the fit for a dose-response curve

Usage

calculateCurveFit(intmat, idx, verbose = TRUE, ...)

Value

List of curve fits.

Arguments

intmat

Intensity matrix as generated by MALDIquant::intensityMatrix() with rownames as the respective concentrations of the spectra.

idx

Numeric vector of the mz indices to perform the fit.

verbose

Logical, print logs to console.

...

Additional arguments passed to nplr::nplr().

Examples

Run this code
data(Blank2022intmat)

# for faster runtime we let it run on 5 peaks only
fits <- calculateCurveFit(Blank2022intmat, idx = 1:5)

Run the code above in your browser using DataLab