powered by
Calculate the fit for a dose-response curve
calculateCurveFit(intmat, idx, verbose = TRUE, ...)
List of curve fits.
Intensity matrix as generated by MALDIquant::intensityMatrix() with rownames as the respective concentrations of the spectra.
MALDIquant::intensityMatrix()
Numeric vector of the mz indices to perform the fit.
Logical, print logs to console.
Additional arguments passed to nplr::nplr().
nplr::nplr()
data(Blank2022intmat) # for faster runtime we let it run on 5 peaks only fits <- calculateCurveFit(Blank2022intmat, idx = 1:5)
Run the code above in your browser using DataLab