Learn R Programming

MALDIcellassay (version 0.4.47)

calculateVPrime: Calculate V'-Factor

Description

Calculate V'-Factor

Usage

calculateVPrime(res, internal = TRUE)

Value

Numeric vector of V'-factors

Arguments

res

Object of class MALDIassay

internal

Logical, currently only the internal implementation, using nConc top and bottom concentrations, is implemented.

Details

The V'-factor is a generalization of the Z'-factor to a dose-response curve. See M.-A. Bray and A. Carpenter, Advanced assay development guidelines for image-based high content screening and analysis for details. It is defined as: $$V' = 1 - 6 * \sigma_f/|\mu_p - \mu_n|$$

with

$$\sigma_f = \sqrt{1/N * \sum{y_fit - y_measured}^2}$$

In other words, \(\sigma_f\) is the standard deviation of residuals.

Note, we do not need to estimate the variance for the mean of the positive and negative value. So, this function uses the top and bottom asymptote directly instead of taking the top and bottom concentrations in consideration.

Examples

Run this code
# see example for `fitCurve()` to see how this data was generated
data(Blank2022res)

calculateVPrime(Blank2022res) 

Run the code above in your browser using DataLab