The V'-factor is a generalization of the Z'-factor to a dose-response curve.
See M.-A. Bray and A. Carpenter, Advanced assay development guidelines for image-based high content screening and analysis for details.
It is defined as:
$$V' = 1 - 6 * \sigma_f/|\mu_p - \mu_n|$$
with
$$\sigma_f = \sqrt{1/N * \sum{y_fit - y_measured}^2}$$
In other words, \(\sigma_f\) is the standard deviation of residuals.
Note, we do not need to estimate the variance for the mean of the positive and negative value.
So, this function uses the top and bottom asymptote directly instead of taking the top and bottom concentrations in consideration.